==> tencent_live_fluttify-0.1.7.tar.gz: lib/src/facade/live_player.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_types, missing_return, unused_import, unused_local_variable, dead_code, unnecessary_cast
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:tencent_live_fluttify/src/android/android.export.g.dart';
import 'package:tencent_live_fluttify/src/ios/ios.export.g.dart';

import 'enums.dart';

part 'player_delegates.dart';

/// 拉流控制器
class LivePlayer extends _Holder with _Community, _Pro {
  LivePlayer._();

  /// 创建一个播放器
  ///
  /// 直播和点播
  /// - 直播（LIVE）的视频源是主播实时推送的。因此，主播停止推送后，播放端的画面也会随即停止，而且由于是实时直播，所以播放器在播直播 URL 的时候是没有进度条的。
  /// - 点播（VOD）的视频源是云端的一个视频文件，只要未被从云端移除，视频就可以随时播放， 播放中您可以通过进度条控制播放位置，腾讯视频和优酷、土豆等视频网站上的视频观看就是典型的点播场景。
  ///
  /// 协议的支持
  /// - FLV 优点: 成熟度高、高并发无压力 缺点: 需集成 SDK 才能播放 播放延迟: 2s - 3s
  /// - RTMP 优点: 优质线路下理论延迟最低	缺点: 高并发情况下表现不佳	播放延迟: 1s - 3s
  /// - HLS（m3u8） 优点: 手机浏览器支持度高 缺点: 延迟非常高	播放延迟: 10s - 30s
  static Future<LivePlayer> create() async {
    return platform(
      android: (pool) async {
        final instance = LivePlayer._();

        final context = await android_app_Application.get();
        instance._androidPlayer = await com_tencent_rtmp_TXLivePlayer
            .create__android_content_Context(context);

        return instance;
      },
      ios: (pool) async {
        final instance = LivePlayer._();

        instance._iosPlayer = await TXLivePlayer.create__();

        return instance;
      },
    );
  }
}

mixin _Community on _Holder {
  /// 设置播放界面
  Future<void> setPlayerView(dynamic playerView) async {
    assert(
      playerView is com_tencent_rtmp_ui_TXCloudVideoView ||
          playerView is UIView,
    );
    return platform(
      android: (pool) async {
        await _androidPlayer.setPlayerView(playerView);
      },
      ios: (pool) async {
        // 其首个参数 frame 在 1.5.2 版本后已经被废弃
        final rect = await CGRect.create(0, 0, 0, 0);
        await _iosPlayer.setupVideoWidget_containView_insertIndex(
          rect,
          playerView,
          0,
        );
      },
    );
  }

  /// 开始播放
  Future<void> startPlay(
    String playUrl, {
    PlayType type = PlayType.RTMP,
  }) async {
    return platform(
      android: (pool) async {
        int _type;
        switch (type) {
          case PlayType.RTMP:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_RTMP;
            break;
          case PlayType.FLV:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_FLV;
            break;
          case PlayType.RTMP_ACC:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_RTMP_ACC;
            break;
          case PlayType.HLS:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_VOD_HLS;
            break;
        }
        final result = await _androidPlayer.startPlay(playUrl, _type);
        debugPrint('result: $result');
      },
      ios: (pool) async {
        TX_Enum_PlayType _type;
        switch (type) {
          case PlayType.RTMP:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_RTMP;
            break;
          case PlayType.FLV:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_FLV;
            break;
          case PlayType.RTMP_ACC:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_RTMP_ACC;
            break;
          case PlayType.HLS:
            _type = TX_Enum_PlayType.PLAY_TYPE_VOD_HLS;
            break;
        }
        final result = await _iosPlayer.startPlay_type(playUrl, _type);
        debugPrint('result: $result');
      },
    );
  }

  /// 恢复播放
  Future<void> resumePlay() async {
    return platform(
      android: (pool) => _androidPlayer.resume(),
      ios: (pool) => _iosPlayer.resume(),
    );
  }

  /// 恢复直播
  Future<int> resumeLive() async {
    return platform(
      android: (pool) => _androidPlayer.resumeLive(),
      ios: (pool) => _iosPlayer.resumeLive(),
    );
  }

  /// 是否在播放中
  Future<bool> isPlaying() async {
    return platform(
      android: (pool) => _androidPlayer.isPlaying(),
      ios: (pool) => _iosPlayer.isPlaying(),
    );
  }

  /// 暂停播放
  Future<void> pausePlay() async {
    return platform(
      android: (pool) => _androidPlayer.pause(),
      ios: (pool) => _iosPlayer.pause(),
    );
  }

  /// 停止播放
  Future<void> stopPlay() async {
    return platform(
      android: (pool) => _androidPlayer.stopPlay(true),
      ios: (pool) => _iosPlayer.stopPlay(),
    );
  }

  /// 事件处理
  Future<void> setOnEventListener({
    VoidCallback onWarningVideoDecodeFail,
    VoidCallback onWarningAudioDecodeFail,
    VoidCallback onWarningReconnect,
    VoidCallback onWarningRecvDataLag,
    VoidCallback onWarningVideoPlayLag,
    VoidCallback onWarningHwAccelerationFail,
    VoidCallback onWarningVideoDiscontinuity,
    VoidCallback onWarningDNSFail,
    VoidCallback onWarningServerConnFail,
    VoidCallback onWarningShakeFail,
    VoidCallback onEventRcvFirstIFrame,
    VoidCallback onEventPlayBegin,
  }) async {
    return platform(
      android: (pool) async {
        await _androidPlayer.setPlayListener(
          _androidEventDelegate
            .._onWarningVideoDecodeFail = onWarningVideoDecodeFail
            .._onWarningAudioDecodeFail = onWarningAudioDecodeFail
            .._onWarningReconnect = onWarningReconnect
            .._onWarningRecvDataLag = onWarningRecvDataLag
            .._onWarningVideoPlayLag = onWarningVideoPlayLag
            .._onWarningHwAccelerationFail = onWarningHwAccelerationFail
            .._onWarningVideoDiscontinuity = onWarningVideoDiscontinuity
            .._onWarningDNSFail = onWarningDNSFail
            .._onWarningServerConnFail = onWarningServerConnFail
            .._onWarningShakeFail = onWarningShakeFail
            .._onEventRcvFirstIFrame = onEventRcvFirstIFrame
            .._onEventPlayBegin = onEventPlayBegin,
        );
      },
      ios: (pool) async {
        await _iosPlayer.set_delegate(
          _iosEventDelegate
            .._onWarningVideoDecodeFail = onWarningVideoDecodeFail
            .._onWarningAudioDecodeFail = onWarningAudioDecodeFail
            .._onWarningReconnect = onWarningReconnect
            .._onWarningRecvDataLag = onWarningRecvDataLag
            .._onWarningVideoPlayLag = onWarningVideoPlayLag
            .._onWarningHwAccelerationFail = onWarningHwAccelerationFail
            .._onWarningVideoDiscontinuity = onWarningVideoDiscontinuity
            .._onWarningDNSFail = onWarningDNSFail
            .._onWarningServerConnFail = onWarningServerConnFail
            .._onWarningShakeFail = onWarningShakeFail
            .._onEventRcvFirstIFrame = onEventRcvFirstIFrame
            .._onEventPlayBegin = onEventPlayBegin,
        );
      },
    );
  }
}

mixin _Pro on _Holder {}

class _Holder {
  com_tencent_rtmp_TXLivePlayer _androidPlayer;
  TXLivePlayer _iosPlayer;

  com_tencent_rtmp_TXLivePlayConfig _androidConfig;
  TXLivePlayConfig _iOSConfig;

  final _androidEventDelegate = _AndroidEventDelegate();
  final _iosEventDelegate = _IOSEventDelegate();
}

==> tencent_live_fluttify-0.2.0.tar.gz: lib/src/facade/live_player.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_types, missing_return, unused_import, unused_local_variable, dead_code, unnecessary_cast
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:tencent_live_fluttify/src/android/android.export.g.dart';
import 'package:tencent_live_fluttify/src/ios/ios.export.g.dart';

import 'cloud_video_controller.dart';
import 'enums.dart';

part 'player_delegates.dart';

/// 拉流控制器
class LivePlayer extends _Holder with _Community, _Pro {
  LivePlayer._();

  /// 创建一个播放器
  ///
  /// 直播和点播
  /// - 直播（LIVE）的视频源是主播实时推送的。因此，主播停止推送后，播放端的画面也会随即停止，而且由于是实时直播，所以播放器在播直播 URL 的时候是没有进度条的。
  /// - 点播（VOD）的视频源是云端的一个视频文件，只要未被从云端移除，视频就可以随时播放， 播放中您可以通过进度条控制播放位置，腾讯视频和优酷、土豆等视频网站上的视频观看就是典型的点播场景。
  ///
  /// 协议的支持
  /// - FLV 优点: 成熟度高、高并发无压力 缺点: 需集成 SDK 才能播放 播放延迟: 2s - 3s
  /// - RTMP 优点: 优质线路下理论延迟最低	缺点: 高并发情况下表现不佳	播放延迟: 1s - 3s
  /// - HLS（m3u8） 优点: 手机浏览器支持度高 缺点: 延迟非常高	播放延迟: 10s - 30s
  static Future<LivePlayer> create() async {
    return platform(
      android: (pool) async {
        final instance = LivePlayer._();

        final context = await android_app_Application.get();
        instance._androidPlayer = await com_tencent_rtmp_TXLivePlayer
            .create__android_content_Context(context);

        return instance;
      },
      ios: (pool) async {
        final instance = LivePlayer._();

        instance._iosPlayer = await TXLivePlayer.create__();

        return instance;
      },
    );
  }
}

mixin _Community on _Holder {
  /// 设置播放界面
  Future<void> setPlayerView(CloudVideoController controller) async {
    return platform(
      android: (pool) async {
        await _androidPlayer.setPlayerView(controller.playerView);
      },
      ios: (pool) async {
        // 其首个参数 frame 在 1.5.2 版本后已经被废弃
        final rect = await CGRect.create(0, 0, 0, 0);
        await _iosPlayer.setupVideoWidget_containView_insertIndex(
          rect,
          controller.playerView,
          0,
        );
      },
    );
  }

  /// 开始播放
  Future<void> startPlay(
    String playUrl, {
    PlayType type = PlayType.RTMP,
  }) async {
    return platform(
      android: (pool) async {
        int _type;
        switch (type) {
          case PlayType.RTMP:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_RTMP;
            break;
          case PlayType.FLV:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_FLV;
            break;
          case PlayType.RTMP_ACC:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_LIVE_RTMP_ACC;
            break;
          case PlayType.HLS:
            _type = com_tencent_rtmp_TXLivePlayer.PLAY_TYPE_VOD_HLS;
            break;
        }
        final result = await _androidPlayer.startPlay(playUrl, _type);
        debugPrint('result: $result');
      },
      ios: (pool) async {
        TX_Enum_PlayType _type;
        switch (type) {
          case PlayType.RTMP:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_RTMP;
            break;
          case PlayType.FLV:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_FLV;
            break;
          case PlayType.RTMP_ACC:
            _type = TX_Enum_PlayType.PLAY_TYPE_LIVE_RTMP_ACC;
            break;
          case PlayType.HLS:
            _type = TX_Enum_PlayType.PLAY_TYPE_VOD_HLS;
            break;
        }
        final result = await _iosPlayer.startPlay_type(playUrl, _type);
        debugPrint('result: $result');
      },
    );
  }

  /// 恢复播放
  Future<void> resumePlay() async {
    return platform(
      android: (pool) => _androidPlayer.resume(),
      ios: (pool) => _iosPlayer.resume(),
    );
  }

  /// 恢复直播
  Future<int> resumeLive() async {
    return platform(
      android: (pool) => _androidPlayer.resumeLive(),
      ios: (pool) => _iosPlayer.resumeLive(),
    );
  }

  /// 是否在播放中
  Future<bool> isPlaying() async {
    return platform(
      android: (pool) => _androidPlayer.isPlaying(),
      ios: (pool) => _iosPlayer.isPlaying(),
    );
  }

  /// 暂停播放
  Future<void> pausePlay() async {
    return platform(
      android: (pool) => _androidPlayer.pause(),
      ios: (pool) => _iosPlayer.pause(),
    );
  }

  /// 停止播放
  Future<void> stopPlay() async {
    return platform(
      android: (pool) => _androidPlayer.stopPlay(true),
      ios: (pool) => _iosPlayer.stopPlay(),
    );
  }

  /// 事件处理
  Future<void> setOnEventListener({
    VoidCallback onWarningVideoDecodeFail,
    VoidCallback onWarningAudioDecodeFail,
    VoidCallback onWarningReconnect,
    VoidCallback onWarningRecvDataLag,
    VoidCallback onWarningVideoPlayLag,
    VoidCallback onWarningHwAccelerationFail,
    VoidCallback onWarningVideoDiscontinuity,
    VoidCallback onWarningDNSFail,
    VoidCallback onWarningServerConnFail,
    VoidCallback onWarningShakeFail,
    VoidCallback onEventRcvFirstIFrame,
    VoidCallback onEventPlayBegin,
  }) async {
    return platform(
      android: (pool) async {
        await _androidPlayer.setPlayListener(
          _androidEventDelegate
            .._onWarningVideoDecodeFail = onWarningVideoDecodeFail
            .._onWarningAudioDecodeFail = onWarningAudioDecodeFail
            .._onWarningReconnect = onWarningReconnect
            .._onWarningRecvDataLag = onWarningRecvDataLag
            .._onWarningVideoPlayLag = onWarningVideoPlayLag
            .._onWarningHwAccelerationFail = onWarningHwAccelerationFail
            .._onWarningVideoDiscontinuity = onWarningVideoDiscontinuity
            .._onWarningDNSFail = onWarningDNSFail
            .._onWarningServerConnFail = onWarningServerConnFail
            .._onWarningShakeFail = onWarningShakeFail
            .._onEventRcvFirstIFrame = onEventRcvFirstIFrame
            .._onEventPlayBegin = onEventPlayBegin,
        );
      },
      ios: (pool) async {
        await _iosPlayer.set_delegate(
          _iosEventDelegate
            .._onWarningVideoDecodeFail = onWarningVideoDecodeFail
            .._onWarningAudioDecodeFail = onWarningAudioDecodeFail
            .._onWarningReconnect = onWarningReconnect
            .._onWarningRecvDataLag = onWarningRecvDataLag
            .._onWarningVideoPlayLag = onWarningVideoPlayLag
            .._onWarningHwAccelerationFail = onWarningHwAccelerationFail
            .._onWarningVideoDiscontinuity = onWarningVideoDiscontinuity
            .._onWarningDNSFail = onWarningDNSFail
            .._onWarningServerConnFail = onWarningServerConnFail
            .._onWarningShakeFail = onWarningShakeFail
            .._onEventRcvFirstIFrame = onEventRcvFirstIFrame
            .._onEventPlayBegin = onEventPlayBegin,
        );
      },
    );
  }
}

mixin _Pro on _Holder {}

class _Holder {
  com_tencent_rtmp_TXLivePlayer _androidPlayer;
  TXLivePlayer _iosPlayer;

  com_tencent_rtmp_TXLivePlayConfig _androidConfig;
  TXLivePlayConfig _iOSConfig;

  final _androidEventDelegate = _AndroidEventDelegate();
  final _iosEventDelegate = _IOSEventDelegate();
}
